@@ -26,11 +26,14 @@
 
 #include <glom/libglom/data_structure/layout/layoutitem_field.h>
 
+namespace Glom
+{
+
 ///field, ascending
 typedef std::pair< sharedptr<const LayoutItem_Field>, bool> type_pair_sort_field;
 typedef std::list<type_pair_sort_field> type_sort_clause;
 
-namespace GlomUtils
+namespace Utils
 {
 
 Glib::ustring trim_whitespace(const Glib::ustring& text);
@@ -39,11 +42,14 @@ Glib::ustring string_replace(const Glib::ustring& src, const Glib::ustring searc
 
 //typedef Base_DB::type_vecLayoutFields type_vecLayoutFields;
 typedef std::vector< sharedptr<LayoutItem_Field> > type_vecLayoutFields;
+typedef std::vector< sharedptr<const LayoutItem_Field> > type_vecConstLayoutFields;
 
   //TODO: Move this to its own file:
 Glib::ustring build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const Glib::ustring& where_clause = Glib::ustring(), const type_sort_clause& sort_clause = type_sort_clause());
+Glib::ustring build_sql_select_with_where_clause(const Glib::ustring& table_name, const type_vecConstLayoutFields& fieldsToGet, const Glib::ustring& where_clause = Glib::ustring(), const type_sort_clause& sort_clause = type_sort_clause());
 
 Glib::ustring build_sql_select_with_key(const Glib::ustring& table_name, const type_vecLayoutFields& fieldsToGet, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_value);
+Glib::ustring build_sql_select_with_key(const Glib::ustring& table_name, const type_vecConstLayoutFields& fieldsToGet, const sharedptr<const Field>& key_field, const Gnome::Gda::Value& key_value);
 
 typedef std::list< std::pair<Gnome::Gda::Value, Gnome::Gda::Value> > type_list_values_with_second;
 type_list_values_with_second get_choice_values(const sharedptr<const LayoutItem_Field>& field);
@@ -65,7 +71,22 @@ Glib::ustring locale_language_id(const Glib::ustring& locale_id);
 
 Glib::ustring create_local_image_uri(const Gnome::Gda::Value& value);
 
-} //namespace GlomUtils
+Glib::ustring string_from_decimal(guint decimal);
+guint decimal_from_string(const Glib::ustring& str);
+
+/** Create an appropriate title for an ID string.
+ * For instance, date_of_birth would become Date Of Birth.
+ */
+Glib::ustring title_from_string(const Glib::ustring& text);
+
+typedef std::vector<Glib::ustring> type_vecStrings;
+type_vecStrings string_separate(const Glib::ustring& str, const Glib::ustring& separator, bool ignore_quoted_separator = false);
+
+Glib::ustring string_trim(const Glib::ustring& str, const Glib::ustring& to_remove);
+
+} //namespace Utils
+
+} //namespace Glom
 
 #endif //GLOM_UTILS_H
 
