@@ -24,6 +24,9 @@
 #include "../../box_db_table.h"
 #include "dialog_fielddefinition.h"
 
+namespace Glom
+{
+
 class Box_DB_Table_Definition : public Box_DB_Table
 {
 public: 
@@ -50,6 +53,8 @@ protected:
 
   virtual void on_Properties_apply();
 
+  bool check_field_change(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field_new);
+
   //Postgres needs some complex stuff:
 
   virtual sharedptr<Field> postgres_change_column(const sharedptr<const Field>& field_old, const sharedptr<const Field>& field);
@@ -64,4 +69,6 @@ protected:
   type_vecFields m_vecFields;
 };
 
+} //namespace Glom
+
 #endif
